macroquad_ldtk is a simple library to load LDtk projects for your macroquad projects.
macroquad_ldtk handles loading the project, trimming editor data, and rendering levels.
Other tasks like collision and entity spawning are left up to the user.