Module types

Types used to represent LDtk resources

Structs

LdtkEntityInstance
Entity instance as placed in LDtk. Should be treated as a spawnpoint, not the actual entity.
LdtkLayerDef
Extra layer data, such as opacity
LdtkLayerInstance
Instances of a layer that hold actual terrain data
LdtkLevel
Contains all data for a specific level
LdtkResources
Struct that holds all necessary resources from an LDtk project. Does not hold all data from the project, only what is needed for its own methods.
LdtkTileInstance
Holds the data of an individual tile.
LdtkTileset
Holds the data for a tileset.

Enums

LdtkLayerType
Layer types selectable in the LDtk editor