Types used to represent LDtk resources
Structs
- Ldtk
Entity Instance - Entity instance as placed in LDtk. Should be treated as a spawnpoint, not the actual entity.
- Ldtk
Layer Def - Extra layer data, such as opacity
- Ldtk
Layer Instance - Instances of a layer that hold actual terrain data
- Ldtk
Level - Contains all data for a specific level
- Ldtk
Resources - Struct that holds all necessary resources from an LDtk project. Does not hold all data from the project, only what is needed for its own methods.
- Ldtk
Tile Instance - Holds the data of an individual tile.
- Ldtk
Tileset - Holds the data for a tileset.
Enums
- Ldtk
Layer Type - Layer types selectable in the LDtk editor